@@ -85,6 +85,8 @@ new KinesisFirehoseToAnalyticsAndS3(scope: Construct, id: string, props: Kinesis
 |existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Existing instance of S3 Bucket object. If this is provided, then also providing bucketProps is an error. |
 |bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|loggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Logging Bucket.|
+|logS3AccessLogs?| boolean|Whether to turn on Access Logging for the S3 bucket. Creates an S3 bucket with associated storage costs for the logs. Enabling Access Logging is a best practice. default - true|
 
 ## Pattern Properties
 
@@ -92,10 +94,11 @@ new KinesisFirehoseToAnalyticsAndS3(scope: Construct, id: string, props: Kinesis
 |:-------------|:----------------|-----------------|
 |kinesisAnalytics|[`kinesisAnalytics.CfnApplication`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisanalytics.CfnApplication.html)|Returns an instance of the Kinesis Analytics application created by the pattern.|
 |kinesisFirehose|[`kinesisFirehose.CfnDeliveryStream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStream.html)|Returns an instance of the Kinesis Firehose delivery stream created by the pattern.|
-|kinesisFirehoseRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis Data Firehose delivery stream|
+|kinesisFirehoseRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis Data Firehose delivery stream.|
 |kinesisFirehoseLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for Kinesis Data Firehose delivery stream|
 |s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the S3 bucket created by the pattern.|
 |s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
+|s3BucketInterface|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Returns an instance of s3.IBucket created by the construct.|
 
 ## Default settings
 
@@ -167,7 +170,9 @@ class KinesisFirehoseToAnalyticsAndS3(
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         kinesis_analytics_props: typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps] = None,
         kinesis_firehose_props: typing.Any = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -176,7 +181,9 @@ class KinesisFirehoseToAnalyticsAndS3(
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
+        :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
 
         :access: public
         :since: 0.8.0
@@ -187,10 +194,12 @@ class KinesisFirehoseToAnalyticsAndS3(
             existing_bucket_obj=existing_bucket_obj,
             kinesis_analytics_props=kinesis_analytics_props,
             kinesis_firehose_props=kinesis_firehose_props,
+            logging_bucket_props=logging_bucket_props,
             log_group_props=log_group_props,
+            log_s3_access_logs=log_s3_access_logs,
         )
 
-        jsii.create(KinesisFirehoseToAnalyticsAndS3, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisAnalytics")
@@ -212,6 +221,11 @@ class KinesisFirehoseToAnalyticsAndS3(
     def kinesis_firehose_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisFirehoseRole"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="s3BucketInterface")
+    def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
+        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
@@ -231,7 +245,9 @@ class KinesisFirehoseToAnalyticsAndS3(
         "existing_bucket_obj": "existingBucketObj",
         "kinesis_analytics_props": "kinesisAnalyticsProps",
         "kinesis_firehose_props": "kinesisFirehoseProps",
+        "logging_bucket_props": "loggingBucketProps",
         "log_group_props": "logGroupProps",
+        "log_s3_access_logs": "logS3AccessLogs",
     },
 )
 class KinesisFirehoseToAnalyticsAndS3Props:
@@ -242,7 +258,9 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         kinesis_analytics_props: typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps] = None,
         kinesis_firehose_props: typing.Any = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties for the KinesisFirehoseToAnalyticsAndS3 class.
 
@@ -250,12 +268,16 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
+        :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_analytics_props, dict):
             kinesis_analytics_props = aws_cdk.aws_kinesisanalytics.CfnApplicationProps(**kinesis_analytics_props)
+        if isinstance(logging_bucket_props, dict):
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {}
@@ -267,8 +289,12 @@ class KinesisFirehoseToAnalyticsAndS3Props:
             self._values["kinesis_analytics_props"] = kinesis_analytics_props
         if kinesis_firehose_props is not None:
             self._values["kinesis_firehose_props"] = kinesis_firehose_props
+        if logging_bucket_props is not None:
+            self._values["logging_bucket_props"] = logging_bucket_props
         if log_group_props is not None:
             self._values["log_group_props"] = log_group_props
+        if log_s3_access_logs is not None:
+            self._values["log_s3_access_logs"] = log_s3_access_logs
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -308,6 +334,15 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         result = self._values.get("kinesis_firehose_props")
         return typing.cast(typing.Any, result)
 
+    @builtins.property
+    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        '''Optional user provided props to override the default props for the S3 Logging Bucket.
+
+        :default: - Default props are used
+        '''
+        result = self._values.get("logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
@@ -317,6 +352,17 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
+    @builtins.property
+    def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
+        '''Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
+
+        Enabling Access Logging is a best practice.
+
+        :default: - true
+        '''
+        result = self._values.get("log_s3_access_logs")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
